pub struct ClickhouseConfig {Show 16 fields
pub endpoint: UriSerde,
pub table: Template,
pub database: Option<Template>,
pub format: Format,
pub skip_unknown_fields: Option<bool>,
pub date_time_best_effort: bool,
pub insert_random_shard: bool,
pub compression: Compression,
pub encoding: Transformer,
pub batch_encoding: Option<ClickhouseBatchEncoding>,
pub batch: BatchConfig<RealtimeSizeBasedDefaultBatchSettings>,
pub auth: Option<Auth>,
pub request: TowerRequestConfig,
pub tls: Option<TlsConfig>,
pub acknowledgements: AcknowledgementsConfig,
pub query_settings: QuerySettingsConfig,
}Expand description
Configuration for the clickhouse sink.
Fields
endpoint: UriSerdeThe endpoint of the ClickHouse server.
table: TemplateThe table that data is inserted into.
database: Option<Template>The database that contains the table that data is inserted into.
format: FormatThe format to parse input data.
skip_unknown_fields: Option<bool>Sets input_format_skip_unknown_fields, allowing ClickHouse to discard fields not present in the table schema.
If left unspecified, use the default provided by the ClickHouse server.
date_time_best_effort: boolSets date_time_input_format to best_effort, allowing ClickHouse to properly parse RFC3339/ISO 8601.
insert_random_shard: boolSets insert_distributed_one_random_shard, allowing ClickHouse to insert data into a random shard when using Distributed Table Engine.
compression: Compressionencoding: Transformerbatch_encoding: Option<ClickhouseBatchEncoding>The batch encoding configuration for encoding events in batches.
When specified, events are encoded together as a single batch.
This is mutually exclusive with per-event encoding based on the format field.
batch: BatchConfig<RealtimeSizeBasedDefaultBatchSettings>auth: Option<Auth>request: TowerRequestConfigtls: Option<TlsConfig>acknowledgements: AcknowledgementsConfigquery_settings: QuerySettingsConfigTrait Implementations
Sourceimpl Clone for ClickhouseConfig
impl Clone for ClickhouseConfig
Sourcefn clone(&self) -> ClickhouseConfig
fn clone(&self) -> ClickhouseConfig
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Configurable for ClickhouseConfig
impl Configurable for ClickhouseConfig
Sourcefn referenceable_name() -> Option<&'static str>
fn referenceable_name() -> Option<&'static str>
Sourcefn generate_schema(
schema_gen: &RefCell<SchemaGenerator>,
) -> Result<SchemaObject, GenerateError>
fn generate_schema( schema_gen: &RefCell<SchemaGenerator>, ) -> Result<SchemaObject, GenerateError>
Sourcefn validate_metadata(_metadata: &Metadata) -> Result<(), GenerateError>where
Self: Sized,
fn validate_metadata(_metadata: &Metadata) -> Result<(), GenerateError>where
Self: Sized,
Sourcefn as_configurable_ref() -> ConfigurableRefwhere
Self: Sized + 'static,
fn as_configurable_ref() -> ConfigurableRefwhere
Self: Sized + 'static,
Sourceimpl Debug for ClickhouseConfig
impl Debug for ClickhouseConfig
Sourceimpl Default for ClickhouseConfig
impl Default for ClickhouseConfig
Sourcefn default() -> ClickhouseConfig
fn default() -> ClickhouseConfig
Sourceimpl<'de> Deserialize<'de> for ClickhouseConfig
impl<'de> Deserialize<'de> for ClickhouseConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl GenerateConfig for ClickhouseConfig
impl GenerateConfig for ClickhouseConfig
fn generate_config() -> Value
Sourceimpl NamedComponent for ClickhouseConfig
impl NamedComponent for ClickhouseConfig
Sourcefn get_component_name(&self) -> &'static str
fn get_component_name(&self) -> &'static str
Sourceimpl Serialize for ClickhouseConfig
impl Serialize for ClickhouseConfig
Sourceimpl SinkConfig for ClickhouseConfig
impl SinkConfig for ClickhouseConfig
Sourcefn build<'life0, 'async_trait>(
&'life0 self,
cx: SinkContext,
) -> Pin<Box<dyn Future<Output = Result<(VectorSink, Healthcheck)>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn build<'life0, 'async_trait>(
&'life0 self,
cx: SinkContext,
) -> Pin<Box<dyn Future<Output = Result<(VectorSink, Healthcheck)>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sourcefn acknowledgements(&self) -> &AcknowledgementsConfig
fn acknowledgements(&self) -> &AcknowledgementsConfig
Sourcefn files_to_watch(&self) -> Vec<&PathBuf>
fn files_to_watch(&self) -> Vec<&PathBuf>